@@ -104,10 +104,10 @@ class ExpaiModelExplainer:
             return response.json()['visualizations']['single_force_plot']
         else:
             if 'error' in response.json().keys():
-                logging.error("There was an error deleting the sample. Please, check the details below. \n {}".format(
+                logging.error("There was an error when explaining the sample. Please, check the details below. \n {}".format(
                     response.json()['error']))
             else:
-                logging.error("There was an error deleting the sample. Please, check the details below. \n {}".format(
+                logging.error("There was an error when explaining the sample. Please, check the details below. \n {}".format(
                     response.json()['message']))
             return None
 
@@ -122,7 +122,7 @@ class ExpaiModelExplainer:
         with open(filepath, 'r') as f:
             return f.read()
 
-    def what_if(self, original_sample: dict = None, modified_sample: dict = None, original_sample_display: dict = None, modified_sample_display: dict = None):
+    def what_if(self, original_sample: dict = None, modified_sample: dict = None, original_sample_display: dict = None, modified_sample_display: dict = None, target_class: int = None):
         assert original_sample is not None and modified_sample is not None, "You must provide an old and new sample to use this module"
         if original_sample_display is not None or modified_sample_display is not None:
             assert original_sample_display is not None and modified_sample_display is not None, "You must provide both display samples."
@@ -138,6 +138,7 @@ class ExpaiModelExplainer:
             "modified_sample": modified_sample,
             "original_sample_display": original_sample_display,
             "modified_sample_display": modified_sample_display,
+            "target_class": target_class
         }
 
         response = self.sess.request("GET",
