@@ -78,10 +78,10 @@ class ExpaiProject:
 
         data = {"model_name_des": model_name,
                 "is_supervised_flag": 1 if is_supervised else 0,
-                'model_category_des': model_category,
-                'model_library_des': model_library,
-                'model_objective_des': model_objective,
-                'model_prediction_type_des': model_prediction_type,
+                'model_category_des': model_category.lower(),
+                'model_library_des': model_library.lower(),
+                'model_objective_des': model_objective.lower(),
+                'model_prediction_type_des': model_prediction_type.lower(),
                 'output_classes_des': ','.join(str(e) for e in output_classes) if output_classes is not None else None}
 
         files = {'model_file': open(model_path, 'rb')}
