@@ -5,12 +5,12 @@ from expai.utils import generate_response
 
 
 class ExpaiLogin:
-    def __init__(self, email: str = None, user_pass: str = None, api_key: str = None):
+    def __init__(self, email: str = None, user_pass: str = None, api_key: str = None, server_name: str = "http://127.0.0.1:5000"):
         assert api_key is not None, "You must provide an api_key"
         assert email is not None, "Please, introduce your user id"
         assert user_pass is not None, "Please, introduce your password"
 
-        self.server_name = "http://127.0.0.1:5000"
+        self.server_name = server_name
         self.api_key = api_key
         self.email = email
 
@@ -116,9 +116,64 @@ class ExpaiLogin:
             logging.error("We could not find your project. Please, check your name or try using project_id as parameter")
             return None
 
+    def update_project(self, project_name: str = None, project_id: str = None, update_info: dict = None):
+        """
+        Update a project
+        """
+        assert project_id is not None or project_name is not None, "You must indicate the project_name or project_id"
+        assert update_info is not None, "You must provide the update_info dictionary with the values to be updated"
+
+        if project_id is None:
+            project_id = self._get_project_id_from_name(project_name)
+
+            if project_id is None:
+                logging.error(
+                    "We could not find any sample matching that name. Please, try again or use sample_id as parameter")
+                return False
+
+        response = self.sess.request("PATCH",
+                                    self.server_name + "/api/projects/{}".format(project_id),
+                                    headers=self.headers, json=update_info)
+
+        if response.ok:
+            return "Project with id {} successfully updated".format(project_id)
+        else:
+            return generate_response(response)
+
     def _get_project_id_from_name(self, project_name: str = None):
         project = self.project_list(exact_search=project_name)
         if project is not None:
             return project['project_id']
 
         return None
+
+    def get_allowed_models(self):
+        """
+        Get a Python object that will enable you to interact with a project and its models.
+        """
+        response = self.sess.request("GET",
+                                     self.server_name + "/api/models/get_allowed",
+                                     headers=self.headers)
+
+        if response.ok:
+            output = {"models_category": generate_response(response, 'models_category'),
+                      "models_objective": generate_response(response, 'models_objective'),
+                      "models_prediction": generate_response(response, 'models_prediction'),
+                      "models_library": generate_response(response, 'models_library')}
+            return output
+        else:
+            return generate_response(response)
+
+    def get_allowed_files(self):
+        """
+        Get a Python object that will enable you to interact with a project and its models.
+        """
+        response = self.sess.request("GET",
+                                     self.server_name + "/api/files/get_allowed",
+                                     headers=self.headers)
+
+        if response.ok:
+            output = {"files_type": generate_response(response, 'files_type')}
+            return output
+        else:
+            return generate_response(response)
